@@ -50,22 +50,3 @@ func NewStatus(engine *core.Engine) Status {
 		Tainted: engine.IsTainted(),
 	}
 }
-
-// GetName gets the entity name, implementation of the interface for the jsonapi
-// Deprecated: use a constant value instead
-// This method will be removed with the one of the PRs of (https://github.com/grafana/k6/issues/911)
-func (s Status) GetName() string {
-	return "status"
-}
-
-// GetID gets a status ID (there is no real ID for the status)
-// Deprecated: use a constant value instead
-// This method will be removed with the one of the PRs of (https://github.com/grafana/k6/issues/911)
-func (s Status) GetID() string {
-	return "default"
-}
-
-// SetID do nothing, required by the jsonapi interface
-func (s Status) SetID(id string) error {
-	return nil
-}
