@@ -37,9 +37,9 @@ import (
 	"go.k6.io/k6/core"
 	"go.k6.io/k6/core/local"
 	"go.k6.io/k6/lib"
-	"go.k6.io/k6/lib/metrics"
 	"go.k6.io/k6/lib/testutils"
 	"go.k6.io/k6/lib/testutils/minirunner"
+	"go.k6.io/k6/metrics"
 )
 
 func TestGetStatus(t *testing.T) {
@@ -47,11 +47,11 @@ func TestGetStatus(t *testing.T) {
 
 	logger := logrus.New()
 	logger.SetOutput(testutils.NewTestOutput(t))
-	execScheduler, err := local.NewExecutionScheduler(&minirunner.MiniRunner{}, logger)
-	require.NoError(t, err)
 	registry := metrics.NewRegistry()
 	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
-	engine, err := core.NewEngine(execScheduler, lib.Options{}, lib.RuntimeOptions{}, nil, logger, builtinMetrics)
+	execScheduler, err := local.NewExecutionScheduler(&minirunner.MiniRunner{}, builtinMetrics, logger)
+	require.NoError(t, err)
+	engine, err := core.NewEngine(execScheduler, lib.Options{}, lib.RuntimeOptions{}, nil, logger, registry)
 	require.NoError(t, err)
 
 	rw := httptest.NewRecorder()
@@ -124,34 +124,44 @@ func TestPatchStatus(t *testing.T) {
 			Payload:            []byte(`{"data":{"type":"status","id":"default","attributes":{"status":0,"paused":null,"vus":10,"vus-max":10,"stopped":false,"running":false,"tainted":false}}}`),
 		},
 	}
-	logger := logrus.New()
-	logger.SetOutput(testutils.NewTestOutput(t))
-
-	scenarios := lib.ScenarioConfigs{}
-	err := json.Unmarshal([]byte(`
-			{"external": {"executor": "externally-controlled",
-			"vus": 0, "maxVUs": 10, "duration": "1s"}}`), &scenarios)
-	require.NoError(t, err)
-	options := lib.Options{Scenarios: scenarios}
-	registry := metrics.NewRegistry()
-	builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
 
 	for name, testCase := range testData {
 		t.Run(name, func(t *testing.T) {
 			t.Parallel()
+			logger := logrus.New()
+			logger.SetOutput(testutils.NewTestOutput(t))
 
-			execScheduler, err := local.NewExecutionScheduler(&minirunner.MiniRunner{Options: options}, logger)
+			scenarios := lib.ScenarioConfigs{}
+			err := json.Unmarshal([]byte(`
+			{"external": {"executor": "externally-controlled",
+			"vus": 0, "maxVUs": 10, "duration": "0"}}`), &scenarios)
 			require.NoError(t, err)
-			engine, err := core.NewEngine(execScheduler, options, lib.RuntimeOptions{}, nil, logger, builtinMetrics)
+			options := lib.Options{Scenarios: scenarios}
+
+			registry := metrics.NewRegistry()
+			builtinMetrics := metrics.RegisterBuiltinMetrics(registry)
+			execScheduler, err := local.NewExecutionScheduler(&minirunner.MiniRunner{Options: options}, builtinMetrics, logger)
 			require.NoError(t, err)
-			ctx, cancel := context.WithTimeout(context.Background(), 2*time.Second)
-			defer cancel()
-			run, _, err := engine.Init(ctx, ctx)
+			engine, err := core.NewEngine(execScheduler, options, lib.RuntimeOptions{}, nil, logger, registry)
 			require.NoError(t, err)
 
-			go func() { _ = run() }()
+			require.NoError(t, engine.OutputManager.StartOutputs())
+			defer engine.OutputManager.StopOutputs()
+
+			ctx, cancel := context.WithTimeout(context.Background(), 2*time.Minute)
+			run, wait, err := engine.Init(ctx, ctx)
+			require.NoError(t, err)
+
+			defer func() {
+				cancel()
+				wait()
+			}()
+
+			go func() {
+				assert.NoError(t, run())
+			}()
 			// wait for the executor to initialize to avoid a potential data race below
-			time.Sleep(100 * time.Millisecond)
+			time.Sleep(200 * time.Millisecond)
 
 			rw := httptest.NewRecorder()
 			NewHandler().ServeHTTP(rw, newRequestWithEngine(engine, "PATCH", "/v1/status", bytes.NewReader(testCase.Payload)))
