@@ -21,8 +21,6 @@
 package cmd
 
 import (
-	"context"
-
 	"github.com/spf13/cobra"
 	"gopkg.in/guregu/null.v3"
 
@@ -30,7 +28,7 @@ import (
 	"go.k6.io/k6/api/v1/client"
 )
 
-func getResumeCmd(ctx context.Context, globalFlags *commandFlags) *cobra.Command {
+func getCmdResume(globalState *globalState) *cobra.Command {
 	// resumeCmd represents the resume command
 	resumeCmd := &cobra.Command{
 		Use:   "resume",
@@ -39,18 +37,18 @@ func getResumeCmd(ctx context.Context, globalFlags *commandFlags) *cobra.Command
 
   Use the global --address flag to specify the URL to the API server.`,
 		RunE: func(cmd *cobra.Command, args []string) error {
-			c, err := client.New(globalFlags.address)
+			c, err := client.New(globalState.flags.address)
 			if err != nil {
 				return err
 			}
-			status, err := c.SetStatus(ctx, v1.Status{
+			status, err := c.SetStatus(globalState.ctx, v1.Status{
 				Paused: null.BoolFrom(false),
 			})
 			if err != nil {
 				return err
 			}
 
-			return yamlPrint(globalFlags.stdout, status)
+			return yamlPrint(globalState.stdOut, status)
 		},
 	}
 	return resumeCmd
