@@ -34,31 +34,37 @@ import (
 	"gopkg.in/guregu/null.v3"
 
 	"go.k6.io/k6/lib/types"
-	"go.k6.io/k6/stats"
+	"go.k6.io/k6/metrics"
 )
 
 func TestOptions(t *testing.T) {
+	t.Parallel()
 	t.Run("Paused", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{Paused: null.BoolFrom(true)})
 		assert.True(t, opts.Paused.Valid)
 		assert.True(t, opts.Paused.Bool)
 	})
 	t.Run("VUs", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{VUs: null.IntFrom(12345)})
 		assert.True(t, opts.VUs.Valid)
 		assert.Equal(t, int64(12345), opts.VUs.Int64)
 	})
 	t.Run("Duration", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{Duration: types.NullDurationFrom(2 * time.Minute)})
 		assert.True(t, opts.Duration.Valid)
 		assert.Equal(t, "2m0s", opts.Duration.String())
 	})
 	t.Run("Iterations", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{Iterations: null.IntFrom(1234)})
 		assert.True(t, opts.Iterations.Valid)
 		assert.Equal(t, int64(1234), opts.Iterations.Int64)
 	})
 	t.Run("Stages", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{Stages: []Stage{
 			{Duration: types.NullDurationFrom(1 * time.Second), Target: null.IntFrom(10)},
 			{Duration: types.NullDurationFrom(2 * time.Second), Target: null.IntFrom(20)},
@@ -84,43 +90,52 @@ func TestOptions(t *testing.T) {
 	})
 	// Execution overwriting is tested by the config consolidation test in cmd
 	t.Run("RPS", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{RPS: null.IntFrom(12345)})
 		assert.True(t, opts.RPS.Valid)
 		assert.Equal(t, int64(12345), opts.RPS.Int64)
 	})
 	t.Run("MaxRedirects", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{MaxRedirects: null.IntFrom(12345)})
 		assert.True(t, opts.MaxRedirects.Valid)
 		assert.Equal(t, int64(12345), opts.MaxRedirects.Int64)
 	})
 	t.Run("UserAgent", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{UserAgent: null.StringFrom("foo")})
 		assert.True(t, opts.UserAgent.Valid)
 		assert.Equal(t, "foo", opts.UserAgent.String)
 	})
 	t.Run("Batch", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{Batch: null.IntFrom(12345)})
 		assert.True(t, opts.Batch.Valid)
 		assert.Equal(t, int64(12345), opts.Batch.Int64)
 	})
 	t.Run("BatchPerHost", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{BatchPerHost: null.IntFrom(12345)})
 		assert.True(t, opts.BatchPerHost.Valid)
 		assert.Equal(t, int64(12345), opts.BatchPerHost.Int64)
 	})
 	t.Run("HTTPDebug", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{HTTPDebug: null.StringFrom("foo")})
 		assert.True(t, opts.HTTPDebug.Valid)
 		assert.Equal(t, "foo", opts.HTTPDebug.String)
 	})
 	t.Run("InsecureSkipTLSVerify", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{InsecureSkipTLSVerify: null.BoolFrom(true)})
 		assert.True(t, opts.InsecureSkipTLSVerify.Valid)
 		assert.True(t, opts.InsecureSkipTLSVerify.Bool)
 	})
 	t.Run("TLSCipherSuites", func(t *testing.T) {
+		t.Parallel()
 		for suiteName, suiteID := range SupportedTLSCipherSuites {
 			t.Run(suiteName, func(t *testing.T) {
+				t.Parallel()
 				opts := Options{}.Apply(Options{TLSCipherSuites: &TLSCipherSuites{suiteID}})
 
 				assert.NotNil(t, opts.TLSCipherSuites)
@@ -130,13 +145,16 @@ func TestOptions(t *testing.T) {
 		}
 
 		t.Run("JSON", func(t *testing.T) {
+			t.Parallel()
 			t.Run("String", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsCipherSuites":["TLS_ECDHE_RSA_WITH_RC4_128_SHA"]}`
 				assert.NoError(t, json.Unmarshal([]byte(jsonStr), &opts))
 				assert.Equal(t, &TLSCipherSuites{tls.TLS_ECDHE_RSA_WITH_RC4_128_SHA}, opts.TLSCipherSuites)
 
 				t.Run("Roundtrip", func(t *testing.T) {
+					t.Parallel()
 					data, err := json.Marshal(opts.TLSCipherSuites)
 					assert.NoError(t, err)
 					assert.Equal(t, `["TLS_ECDHE_RSA_WITH_RC4_128_SHA"]`, string(data))
@@ -146,11 +164,13 @@ func TestOptions(t *testing.T) {
 				})
 			})
 			t.Run("Not a string", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsCipherSuites":[1.2]}`
 				assert.Error(t, json.Unmarshal([]byte(jsonStr), &opts))
 			})
 			t.Run("Unknown cipher", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsCipherSuites":["foo"]}`
 				assert.Error(t, json.Unmarshal([]byte(jsonStr), &opts))
@@ -158,6 +178,7 @@ func TestOptions(t *testing.T) {
 		})
 	})
 	t.Run("TLSVersion", func(t *testing.T) {
+		t.Parallel()
 		versions := TLSVersions{Min: tls.VersionSSL30, Max: tls.VersionTLS12}
 		opts := Options{}.Apply(Options{TLSVersion: &versions})
 
@@ -166,7 +187,9 @@ func TestOptions(t *testing.T) {
 		assert.Equal(t, opts.TLSVersion.Max, TLSVersion(tls.VersionTLS12))
 
 		t.Run("JSON", func(t *testing.T) {
+			t.Parallel()
 			t.Run("Object", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsVersion":{"min":"tls1.0","max":"tls1.2"}}`
 				assert.NoError(t, json.Unmarshal([]byte(jsonStr), &opts))
@@ -176,6 +199,7 @@ func TestOptions(t *testing.T) {
 				}, opts.TLSVersion)
 
 				t.Run("Roundtrip", func(t *testing.T) {
+					t.Parallel()
 					data, err := json.Marshal(opts.TLSVersion)
 					assert.NoError(t, err)
 					assert.Equal(t, `{"min":"tls1.0","max":"tls1.2"}`, string(data))
@@ -185,6 +209,7 @@ func TestOptions(t *testing.T) {
 				})
 			})
 			t.Run("String", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsVersion":"tls1.2"}`
 				assert.NoError(t, json.Unmarshal([]byte(jsonStr), &opts))
@@ -194,17 +219,20 @@ func TestOptions(t *testing.T) {
 				}, opts.TLSVersion)
 			})
 			t.Run("Blank", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsVersion":""}`
 				assert.NoError(t, json.Unmarshal([]byte(jsonStr), &opts))
 				assert.Equal(t, &TLSVersions{}, opts.TLSVersion)
 			})
 			t.Run("Not a string", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsVersion":1.2}`
 				assert.Error(t, json.Unmarshal([]byte(jsonStr), &opts))
 			})
 			t.Run("Unsupported version", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"tlsVersion":"-1"}`
 				assert.Error(t, json.Unmarshal([]byte(jsonStr), &opts))
@@ -215,6 +243,7 @@ func TestOptions(t *testing.T) {
 		})
 	})
 	t.Run("TLSAuth", func(t *testing.T) {
+		t.Parallel()
 		tlsAuth := []*TLSAuth{
 			{TLSAuthFields{
 				Domains: []string{"example.com", "*.example.com"},
@@ -259,6 +288,7 @@ func TestOptions(t *testing.T) {
 		assert.Equal(t, tlsAuth, opts.TLSAuth)
 
 		t.Run("Roundtrip", func(t *testing.T) {
+			t.Parallel()
 			optsData, err := json.Marshal(opts)
 			assert.NoError(t, err)
 
@@ -275,33 +305,140 @@ func TestOptions(t *testing.T) {
 		})
 
 		t.Run("Invalid JSON", func(t *testing.T) {
+			t.Parallel()
 			var opts Options
 			jsonStr := `{"tlsAuth":["invalid"]}`
 			assert.Error(t, json.Unmarshal([]byte(jsonStr), &opts))
 		})
 
 		t.Run("Certificate error", func(t *testing.T) {
+			t.Parallel()
 			var opts Options
 			jsonStr := `{"tlsAuth":[{"Cert":""}]}`
 			assert.Error(t, json.Unmarshal([]byte(jsonStr), &opts))
 		})
 	})
+	t.Run("TLSAuth with", func(t *testing.T) {
+		t.Parallel()
+		domains := []string{"example.com", "*.example.com"}
+		cert := "-----BEGIN CERTIFICATE-----\n" +
+			"MIIBoTCCAUegAwIBAgIUQl0J1Gkd6U2NIMwMDnpfH8c1myEwCgYIKoZIzj0EAwIw\n" +
+			"EDEOMAwGA1UEAxMFTXkgQ0EwHhcNMTcwODE1MTYxODAwWhcNMTgwODE1MTYxODAw\n" +
+			"WjAQMQ4wDAYDVQQDEwV1c2VyMTBZMBMGByqGSM49AgEGCCqGSM49AwEHA0IABLaf\n" +
+			"xEOmBHkzbqd9/0VZX/39qO2yQq2Gz5faRdvy38kuLMCV+9HYrfMx6GYCZzTUIq6h\n" +
+			"8QXOrlgYTixuUVfhJNWjfzB9MA4GA1UdDwEB/wQEAwIFoDAdBgNVHSUEFjAUBggr\n" +
+			"BgEFBQcDAQYIKwYBBQUHAwIwDAYDVR0TAQH/BAIwADAdBgNVHQ4EFgQUxmQiq5K3\n" +
+			"KUnVME945Byt3Ysvkh8wHwYDVR0jBBgwFoAU3qEhcpRgpsqo9V+LFns9a+oZIYww\n" +
+			"CgYIKoZIzj0EAwIDSAAwRQIgSGxnJ+/cLUNTzt7fhr/mjJn7ShsTW33dAdfLM7H2\n" +
+			"z/gCIQDyVf8DePtxlkMBScTxZmIlMQdNc6+6VGZQ4QscruVLmg==\n" +
+			"-----END CERTIFICATE-----"
+		tests := []struct {
+			name         string
+			privateKey   string
+			password     string
+			hasError     bool
+			errorMessage string
+		}{
+			{
+				name: "encrypted key and invalid password",
+				privateKey: "-----BEGIN EC PRIVATE KEY-----\n" +
+					"Proc-Type: 4,ENCRYPTED\n" +
+					"DEK-Info: AES-256-CBC,DF2445CBFE2E5B112FB2B721063757E5\n" +
+					"o/VKNZjQcRM2hatqUkQ0dTolL7i2i5hJX9XYsl+TMsq8ZkC83uY/JdR986QS+W2c\n" +
+					"EoQGtVGVeL0KGvGpzjTX3YAKXM7Lg5btAeS8GvJ9S7YFd8s0q1pqDdffl2RyjJav\n" +
+					"t1jx6XvLu2nBrOUARvHqjkkJQCTdRf2a34GJdbZqE+4=\n" +
+					"-----END EC PRIVATE KEY-----",
+				password:     "iZfYGcrgFHOg4nweEo7ufT",
+				hasError:     true,
+				errorMessage: "x509: decryption password incorrect",
+			},
+			{
+				name: "encrypted key and valid password",
+				privateKey: "-----BEGIN EC PRIVATE KEY-----\n" +
+					"Proc-Type: 4,ENCRYPTED\n" +
+					"DEK-Info: AES-256-CBC,DF2445CBFE2E5B112FB2B721063757E5\n" +
+					"o/VKNZjQcRM2hatqUkQ0dTolL7i2i5hJX9XYsl+TMsq8ZkC83uY/JdR986QS+W2c\n" +
+					"EoQGtVGVeL0KGvGpzjTX3YAKXM7Lg5btAeS8GvJ9S7YFd8s0q1pqDdffl2RyjJav\n" +
+					"t1jx6XvLu2nBrOUARvHqjkkJQCTdRf2a34GJdbZqE+4=\n" +
+					"-----END EC PRIVATE KEY-----",
+				password:     "12345",
+				hasError:     false,
+				errorMessage: "",
+			},
+			{
+				name: "encrypted pks8 format key and valid password",
+				privateKey: "-----BEGIN ENCRYPTED PRIVATE KEY-----\n" +
+					"MIHsMFcGCSqGSIb3DQEFDTBKMCkGCSqGSIb3DQEFDDAcBAjcfarGfrRgUgICCAAw\n" +
+					"DAYIKoZIhvcNAgkFADAdBglghkgBZQMEASoEEFmtmKEFmThbkbpxmC6iBvoEgZCE\n" +
+					"pDCpH/yCLmSpjdi/PC74I794nzHyCWf/oS0JhM0Q7J+abZP+p5pnreKft1f15Dbw\n" +
+					"QG9alfoM6EffJcVo3gf1tgQrpGGFMwczc4VhQgSGDy0XjZSbd2K0QCFGSmD2ZIR1\n" +
+					"qPG3WepWjKmIsYffGeKZx+FjXHSFeGk7RnssNAyKcPruDQIdWWyXxX1+ugBKuBw=\n" +
+					"-----END ENCRYPTED PRIVATE KEY-----\n",
+				password:     "12345",
+				hasError:     true,
+				errorMessage: "encrypted pkcs8 formatted key is not supported",
+			},
+			{
+				name: "non encrypted key and password",
+				privateKey: "-----BEGIN EC PRIVATE KEY-----\n" +
+					"MHcCAQEEINVilD5qOBkSy+AYfd41X0QPB5N3Z6OzgoBj8FZmSJOFoAoGCCqGSM49\n" +
+					"AwEHoUQDQgAEF8XzmC7x8Ns0Y2Wyu2c77ge+6I/ghcDTjWOMZzMPmRRDxqKFLuGD\n" +
+					"zW1Kss13WODGSS8+j7dNCPOeLKyK6cbeIg==\n" +
+					"-----END EC PRIVATE KEY-----",
+				password:     "12345",
+				hasError:     true,
+				errorMessage: "x509: no DEK-Info header in block",
+			},
+		}
+		for _, tc := range tests {
+			t.Run(tc.name, func(t *testing.T) {
+				tlsAuth := []*TLSAuth{
+					{TLSAuthFields{
+						Domains:  domains,
+						Cert:     cert,
+						Key:      tc.privateKey,
+						Password: null.StringFrom(tc.password),
+					}, nil},
+				}
+				opts := Options{}.Apply(Options{TLSAuth: tlsAuth})
+				assert.Equal(t, tlsAuth, opts.TLSAuth)
+
+				t.Run("Roundtrip", func(t *testing.T) {
+					optsData, err := json.Marshal(opts)
+					assert.NoError(t, err)
+
+					var opts2 Options
+					err = json.Unmarshal(optsData, &opts2)
+					if tc.hasError {
+						assert.Error(t, err)
+						assert.Contains(t, err.Error(), tc.errorMessage)
+					} else {
+						assert.NoError(t, err)
+					}
+				})
+			})
+		}
+	})
 	t.Run("NoConnectionReuse", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{NoConnectionReuse: null.BoolFrom(true)})
 		assert.True(t, opts.NoConnectionReuse.Valid)
 		assert.True(t, opts.NoConnectionReuse.Bool)
 	})
 	t.Run("NoVUConnectionReuse", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{NoVUConnectionReuse: null.BoolFrom(true)})
 		assert.True(t, opts.NoVUConnectionReuse.Valid)
 		assert.True(t, opts.NoVUConnectionReuse.Bool)
 	})
 	t.Run("NoCookiesReset", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{NoCookiesReset: null.BoolFrom(true)})
 		assert.True(t, opts.NoCookiesReset.Valid)
 		assert.True(t, opts.NoCookiesReset.Bool)
 	})
 	t.Run("BlacklistIPs", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{
 			BlacklistIPs: []*IPNet{{
 				IPNet: net.IPNet{
@@ -329,6 +466,7 @@ func TestOptions(t *testing.T) {
 		})
 	})
 	t.Run("BlockedHostnames", func(t *testing.T) {
+		t.Parallel()
 		blockedHostnames, err := types.NewNullHostnameTrie([]string{"test.k6.io", "*valid.pattern"})
 		require.NoError(t, err)
 		opts := Options{}.Apply(Options{BlockedHostnames: blockedHostnames})
@@ -337,6 +475,7 @@ func TestOptions(t *testing.T) {
 	})
 
 	t.Run("Hosts", func(t *testing.T) {
+		t.Parallel()
 		host, err := NewHostAddress(net.ParseIP("192.0.2.1"), "80")
 		assert.NoError(t, err)
 
@@ -349,27 +488,31 @@ func TestOptions(t *testing.T) {
 	})
 
 	t.Run("Throws", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{Throw: null.BoolFrom(true)})
 		assert.True(t, opts.Throw.Valid)
 		assert.Equal(t, true, opts.Throw.Bool)
 	})
 
 	t.Run("Thresholds", func(t *testing.T) {
-		opts := Options{}.Apply(Options{Thresholds: map[string]stats.Thresholds{
+		t.Parallel()
+		opts := Options{}.Apply(Options{Thresholds: map[string]metrics.Thresholds{
 			"metric": {
-				Thresholds: []*stats.Threshold{{}},
+				Thresholds: []*metrics.Threshold{{}},
 			},
 		}})
 		assert.NotNil(t, opts.Thresholds)
 		assert.NotEmpty(t, opts.Thresholds)
 	})
 	t.Run("External", func(t *testing.T) {
+		t.Parallel()
 		ext := map[string]json.RawMessage{"a": json.RawMessage("1")}
 		opts := Options{}.Apply(Options{External: ext})
 		assert.Equal(t, ext, opts.External)
 	})
 
 	t.Run("JSON", func(t *testing.T) {
+		t.Parallel()
 		data, err := json.Marshal(Options{})
 		assert.NoError(t, err)
 		var opts Options
@@ -377,62 +520,73 @@ func TestOptions(t *testing.T) {
 		assert.Equal(t, Options{}, opts)
 	})
 	t.Run("SystemTags", func(t *testing.T) {
-		opts := Options{}.Apply(Options{SystemTags: stats.NewSystemTagSet(stats.TagProto)})
+		t.Parallel()
+		opts := Options{}.Apply(Options{SystemTags: metrics.NewSystemTagSet(metrics.TagProto)})
 		assert.NotNil(t, opts.SystemTags)
 		assert.NotEmpty(t, opts.SystemTags)
-		assert.True(t, opts.SystemTags.Has(stats.TagProto))
+		assert.True(t, opts.SystemTags.Has(metrics.TagProto))
 
 		t.Run("JSON", func(t *testing.T) {
+			t.Parallel()
 			t.Run("Array", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"systemTags":["url"]}`
 				assert.NoError(t, json.Unmarshal([]byte(jsonStr), &opts))
-				assert.Equal(t, *stats.NewSystemTagSet(stats.TagURL), *opts.SystemTags)
+				assert.Equal(t, *metrics.NewSystemTagSet(metrics.TagURL), *opts.SystemTags)
 
 				t.Run("Roundtrip", func(t *testing.T) {
+					t.Parallel()
 					data, err := json.Marshal(opts.SystemTags)
 					assert.NoError(t, err)
 					assert.Equal(t, `["url"]`, string(data))
-					var vers2 stats.SystemTagSet
+					var vers2 metrics.SystemTagSet
 					assert.NoError(t, json.Unmarshal(data, &vers2))
 					assert.Equal(t, vers2, *opts.SystemTags)
 				})
 			})
 			t.Run("Blank", func(t *testing.T) {
+				t.Parallel()
 				var opts Options
 				jsonStr := `{"systemTags":[]}`
 				assert.NoError(t, json.Unmarshal([]byte(jsonStr), &opts))
-				assert.Equal(t, stats.SystemTagSet(0), *opts.SystemTags)
+				assert.Equal(t, metrics.SystemTagSet(0), *opts.SystemTags)
 			})
 		})
 	})
 	t.Run("SummaryTrendStats", func(t *testing.T) {
+		t.Parallel()
 		stats := []string{"myStat1", "myStat2"}
 		opts := Options{}.Apply(Options{SummaryTrendStats: stats})
 		assert.Equal(t, stats, opts.SummaryTrendStats)
 	})
 	t.Run("RunTags", func(t *testing.T) {
-		tags := stats.IntoSampleTags(&map[string]string{"myTag": "hello"})
+		t.Parallel()
+		tags := metrics.IntoSampleTags(&map[string]string{"myTag": "hello"})
 		opts := Options{}.Apply(Options{RunTags: tags})
 		assert.Equal(t, tags, opts.RunTags)
 	})
 	t.Run("DiscardResponseBodies", func(t *testing.T) {
+		t.Parallel()
 		opts := Options{}.Apply(Options{DiscardResponseBodies: null.BoolFrom(true)})
 		assert.True(t, opts.DiscardResponseBodies.Valid)
 		assert.True(t, opts.DiscardResponseBodies.Bool)
 	})
 	t.Run("ClientIPRanges", func(t *testing.T) {
-		clientIPRanges, err := types.NewIPPool("129.112.232.12,123.12.0.0/32")
+		t.Parallel()
+		clientIPRanges := types.NullIPPool{}
+		err := clientIPRanges.UnmarshalText([]byte("129.112.232.12,123.12.0.0/32"))
 		require.NoError(t, err)
-		opts := Options{}.Apply(Options{LocalIPs: types.NullIPPool{Pool: clientIPRanges, Valid: true}})
+		opts := Options{}.Apply(Options{LocalIPs: clientIPRanges})
 		assert.NotNil(t, opts.LocalIPs)
 	})
 }
 
 func TestOptionsEnv(t *testing.T) {
 	t.Parallel()
-	mustIPPool := func(s string) *types.IPPool {
-		p, err := types.NewIPPool(s)
+	mustNullIPPool := func(s string) types.NullIPPool {
+		p := types.NullIPPool{}
+		err := p.UnmarshalText([]byte(s))
 		require.NoError(t, err)
 		return p
 	}
@@ -508,8 +662,8 @@ func TestOptionsEnv(t *testing.T) {
 		},
 		{"LocalIPs", "K6_LOCAL_IPS"}: {
 			"":                 types.NullIPPool{},
-			"192.168.220.2":    types.NullIPPool{Pool: mustIPPool("192.168.220.2"), Valid: true},
-			"192.168.220.2/24": types.NullIPPool{Pool: mustIPPool("192.168.220.0/24"), Valid: true},
+			"192.168.220.2":    mustNullIPPool("192.168.220.2"),
+			"192.168.220.0/24": mustNullIPPool("192.168.220.0/24"),
 		},
 		{"Throw", "K6_THROW"}: {
 			"":      null.Bool{},
@@ -547,6 +701,7 @@ func TestOptionsEnv(t *testing.T) {
 }
 
 func TestCIDRUnmarshal(t *testing.T) {
+	t.Parallel()
 	testData := []struct {
 		input          string
 		expectedOutput *IPNet
@@ -576,6 +731,7 @@ func TestCIDRUnmarshal(t *testing.T) {
 	for _, data := range testData {
 		data := data
 		t.Run(data.input, func(t *testing.T) {
+			t.Parallel()
 			actualIPNet := &IPNet{}
 			err := actualIPNet.UnmarshalText([]byte(data.input))
 
@@ -591,6 +747,7 @@ func TestCIDRUnmarshal(t *testing.T) {
 }
 
 func TestHostAddressUnmarshal(t *testing.T) {
+	t.Parallel()
 	testData := []struct {
 		input          string
 		expectedOutput *HostAddress
@@ -636,6 +793,7 @@ func TestHostAddressUnmarshal(t *testing.T) {
 	for _, data := range testData {
 		data := data
 		t.Run(data.input, func(t *testing.T) {
+			t.Parallel()
 			actualHost := &HostAddress{}
 			err := actualHost.UnmarshalText([]byte(data.input))
 
